@@ -461,12 +461,12 @@ class WorkflowManager:
         return wf.name
 
     def get_pending_workflows(self, workflow_namespace: str) -> int:
-        """Get the total number of workflows in a given namespace."""
-        return len(
-            self.api.list_namespaced_workflows(
-                workflow_namespace, labels="workflows.argoproj.io/phase=Pending"
-            ).items
-        )
+        """Get the total number of pending workflows in a given namespace."""
+        count = 0
+        for i in self.api.list_namespaced_workflows(workflow_namespace).items:
+            count += i.status.started_at is None
+
+        return count
 
     def submit_workflow_from_template(
         self,
@@ -661,6 +661,56 @@ class WorkflowManager:
 
         return workflow_id
 
+    def submit_kebechet_administrator(
+        self,
+        template_parameters: Optional[Dict[str, str]] = None,
+        workflow_parameters: Optional[Dict[str, Any]] = None,
+    ) -> Optional[str]:
+        """Submit Kebechet Administrator Workflow for an internal trigger message."""
+        if not self.openshift.infra_namespace:
+            raise ConfigurationError("Infra namespace was not provided.")
+
+        if not self.openshift.backend_namespace:
+            raise ConfigurationError("Backend namespace was not provided.")
+
+        template_parameters = template_parameters or {}
+        workflow_parameters = workflow_parameters or {}
+
+        workflow_id: Optional[str] = self.submit_workflow_from_template(
+            self.openshift.infra_namespace,
+            label_selector="template=kebechet-administrator",
+            template_parameters=template_parameters,
+            workflow_parameters=workflow_parameters,
+            workflow_namespace=self.openshift.backend_namespace,
+        )
+
+        return workflow_id
+
+    def submit_kebechet_run_url(
+        self,
+        template_parameters: Optional[Dict[str, str]] = None,
+        workflow_parameters: Optional[Dict[str, Any]] = None,
+    ) -> Optional[str]:
+        """Submit Kebechet Run-URL Workflow for a single slug."""
+        if not self.openshift.infra_namespace:
+            raise ConfigurationError("Infra namespace was not provided.")
+
+        if not self.openshift.backend_namespace:
+            raise ConfigurationError("Backend namespace was not provided.")
+
+        template_parameters = template_parameters or {}
+        workflow_parameters = workflow_parameters or {}
+
+        workflow_id: Optional[str] = self.submit_workflow_from_template(
+            self.openshift.infra_namespace,
+            label_selector="template=kebechet-run-url",
+            template_parameters=template_parameters,
+            workflow_parameters=workflow_parameters,
+            workflow_namespace=self.openshift.backend_namespace,
+        )
+
+        return workflow_id
+
     def submit_solver(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
@@ -807,3 +857,28 @@ class WorkflowManager:
         )
 
         return workflow_id
+
+    def submit_graph_sync(
+        self,
+        template_parameters: Optional[Dict[str, str]] = None,
+        workflow_parameters: Optional[Dict[str, Any]] = None,
+    ) -> Optional[str]:
+        """Submit graph-sync workflow."""
+        if not self.openshift.infra_namespace:
+            raise ConfigurationError("Infra namespace was not provided.")
+
+        if not self.openshift.middletier_namespace:
+            raise ConfigurationError("Middletier namespace was not provided.")
+
+        template_parameters = template_parameters or {}
+        workflow_parameters = workflow_parameters or {}
+
+        workflow_id: Optional[str] = self.submit_workflow_from_template(
+            self.openshift.infra_namespace,
+            label_selector="template=graph-sync",
+            template_parameters=template_parameters,
+            workflow_parameters=workflow_parameters,
+            workflow_namespace=self.openshift.middletier_namespace,
+        )
+
+        return workflow_id
